<?php

namespace Dedi\SyliusBlogPlugin\Entity;

use Dedi\SyliusBlogPlugin\Domain\SEO\Adapter\ReferableInterface;
use Sylius\Component\Resource\Model\TranslatableInterface;
use Sylius\Component\Resource\Model\TranslatableTrait;
use Sylius\Component\Resource\Model\TranslationInterface;

abstract class AbstractReferable implements TranslatableInterface, ReferableInterface
{
    use TranslatableTrait {
        __construct as private initializeTranslationsCollection;
        getTranslation as private doGetTranslation;
    }

    public function __construct()
    {
        $this->initializeTranslationsCollection();
    }

    public function isIndexable(): bool
    {
        return $this->getTranslation()->isIndexable();
    }

    public function setIndexable(bool $indexable): self
    {
        $this->getTranslation()->setIndexable($indexable);

        return $this;
    }

    public function isMetadataEnabled(): bool
    {
        return $this->getTranslation()->isEnabled();
    }

    public function setMetadataEnabled(bool $enabled): self
    {
        $this->getTranslation()->setEnabled($enabled);

        return $this;
    }

    public function getMetadataTitle(): ?string
    {
        return $this->getTranslation()->getMetadataTitle();
    }

    public function setMetadataTitle(?string $title): self
    {
        $this->getTranslation()->setMetadataTitle($title);

        return $this;
    }

    public function getMetadataUrl(): ?string
    {
        return $this->getTranslation()->getMetadataUrl();
    }

    public function setMetadataUrl(?string $url): self
    {
        $this->getTranslation()->setMetadataUrl($url);

        return $this;
    }

    public function getMetadataType(): ?string
    {
        return $this->getTranslation()->getMetadataType();
    }

    public function setMetadataType(?string $type): self
    {
        $this->getTranslation()->setMetadataType($type);

        return $this;
    }

    public function getMetadataDescription(): ?string
    {
        return $this->getTranslation()->getMetadataDescription();
    }

    public function setMetadataDescription(?string $description): self
    {
        $this->getTranslation()->setMetadataDescription($description);

        return $this;
    }

    public function getMetadataImage(): ?string
    {
        return $this->getTranslation()->getMetadataImage();
    }

    public function setMetadataImage(?string $path): self
    {
        $this->getTranslation()->setMetadataImage($path);

        return $this;
    }

    public function getTranslation(?string $locale = null): TranslationInterface
    {
        /** @var AbstractReferableTranslation $translation */
        $translation = $this->doGetTranslation($locale);

        return $translation;
    }
}
